AppErrorModel class
Repesents an Error generated as a response
Constructors
- AppErrorModel({dynamic message = "", Exception? exception, StackTrace? stackTrace, int code = -1})
Properties
- code ↔ int
-
getter/setter pair
- exception ↔ Exception?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace ↔ StackTrace?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited