DataResponseModel<T> class
Maps the response to model
Constructors
- DataResponseModel({T? data, AppErrorModel? appErrorModel, int statusCode = -1, String? printLogMessage})
-
const
Properties
- appErrorModel → AppErrorModel?
-
final
- data → T?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- printLogMessage → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited