EventMultipartFileUploadModel class

Constructors

EventMultipartFileUploadModel({required String fieldName, String? fileName, String? filePath, Uint8List? bytes})
const

Properties

bytes Uint8List?
final
fieldName String
final
fileName String?
final
filePath String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited